@@ -1,4 +1,6 @@
-from typing import Dict, Generic, Optional, Sequence, TypeVar, Union
+import contextlib
+from pathlib import Path
+from typing import Any, Callable, Dict, Generic, Optional, Sequence, TypeVar, Union
 import h5py
 import numpy as np
 
@@ -9,6 +11,7 @@ except ImportError:
 
 from .models import LinkResolution, Selection
 from .utils import (
+    NotFoundError,
     attr_metadata,
     convert,
     get_array_stats,
@@ -126,8 +129,8 @@ class ResolvedEntityContent(EntityContent, Generic[T]):
             (
                 "attributes",
                 [
-                    attr_metadata(self._h5py_entity.attrs.get_id(k))
-                    for k in attribute_names
+                    attr_metadata(self._h5py_entity.attrs, name)
+                    for name in attribute_names
                 ],
             ),
             *super().metadata().items(),
@@ -264,3 +267,28 @@ def create_content(
         return ResolvedEntityContent(path, entity)
 
     raise TypeError(f"h5py type {type(entity)} not supported")
+
+
+@contextlib.contextmanager
+def get_content_from_file(
+    filepath: Union[str, Path],
+    path: Optional[str],
+    create_error: Callable[[int, str], Exception],
+    resolve_links: LinkResolution = LinkResolution.ONLY_VALID,
+    h5py_options: Dict[str, Any] = {},
+):
+    try:
+        f = h5py.File(filepath, "r", **h5py_options)
+    except OSError as e:
+        if isinstance(e, FileNotFoundError) or "No such file or directory" in str(e):
+            raise create_error(404, "File not found!")
+        if isinstance(e, PermissionError) or "Permission denied" in str(e):
+            raise create_error(403, "Cannot read file: Permission denied!")
+        raise e
+
+    try:
+        yield create_content(f, path, resolve_links)
+    except NotFoundError as e:
+        raise create_error(404, str(e))
+    finally:
+        f.close()
